************
Contributors
************

.. spelling::
   McGregor
   Grimwood
   FOSSi
   Solarflare

cocotb is developed and maintained by an active community.
Our GitHub repository contains a list of all `contributors <https://github.com/cocotb/cocotb/graphs/contributors>`_.

Since mid-2018 cocotb is an independent project under the umbrella of the
`Free and Open Source Silicon Foundation <https://www.fossi-foundation.org>`_.
The FOSSi Foundation provides the cocotb project with financial,
legal and administrative support, and holds cocotb assets.

cocotb was originally developed by Stuart Hodgson and Chris Higgs of Potential Ventures
with the support of Solarflare Communications Ltd.
and contributions from Gordon McGregor and Finn Grimwood.
